@@ -1,13 +1,14 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 __author__ = "Mikhail Fedosov (tbs.micle@gmail.com)"
-__version__ = "0.1.3"
+__version__ = "0.1.3.1"
 
 # http://code.activestate.com/recipes/577708-check-for-package-updates-on-pypi-works-best-in-pi/
 # http://stackoverflow.com/questions/287871/print-in-terminal-with-colors-using-python
 
 import pip
 import sys
+import socket
 import xmlrpclib
 from multiprocessing import Pool
 
@@ -54,24 +55,30 @@ if sys.platform == "win32":
 
 def check_package(dist):
 	pypi = xmlrpclib.ServerProxy("http://pypi.python.org/pypi")
-	available = pypi.package_releases(dist.project_name)
-	if not available:
-		# try to capitalize pkg name
-		available = pypi.package_releases(dist.project_name.capitalize())
 
-	if not available:
-		msg = colors.FAIL + u"{symbols.FAIL}not found at PyPI".format(symbols=symbols) + colors.ENDC
-	elif available[0] != dist.version:
-		msg = u"{colors.OKGREEN}{symbols.UPDATE}{colors.BOLD}{version}{colors.ENDC}".format(colors=colors, symbols=symbols, version=available[0])
-	else:
-		if "-v" in sys.argv:
-			msg = u"{symbols.OK}up to date".format(colors=colors, symbols=symbols)
+	try:
+		available = pypi.package_releases(dist.project_name)
+		if not available:
+			# try to capitalize pkg name
+			available = pypi.package_releases(dist.project_name.capitalize())
+
+		if not available:
+			msg = u"{colors.FAIL}{symbols.FAIL}not found at PyPI{colors.ENDC}".format(colors=colors, symbols=symbols)
+		elif available[0] != dist.version:
+			msg = u"{colors.OKGREEN}{symbols.UPDATE}{colors.BOLD}{version}{colors.ENDC}".format(colors=colors, symbols=symbols, version=available[0])
 		else:
-			msg = ""
+			if "-v" in sys.argv:
+				msg = u"{symbols.OK}up to date".format(colors=colors, symbols=symbols)
+			else:
+				msg = ""
+	except socket.timeout:
+		msg = u"{colors.FAIL}{symbols.FAIL}timeout{colors.ENDC}".format(colors=colors, symbols=symbols)
+
 	if msg:
 		print(u"{dist.project_name:26} {colors.BOLD}{dist.version:12}{colors.ENDC} {msg}".format(colors=colors, dist=dist, msg=msg))
 
 def main():
+	socket.setdefaulttimeout(5.0)
 	pypi_pool = Pool()
 	pypi_pool.map(check_package, pip.get_installed_distributions())
 
